@@ -22,17 +22,20 @@
 #'   \code{"jbessel"}, \code{"gravity"}, \code{"rquad"},
 #'   \code{"magnetic"}, \code{"matern"}, \code{"cauchy"}, \code{"pexponential"},
 #'   and \code{"none"}. Parameterizations of each spatial covariance type are
-#'   available in Details. When \code{spcov_type} is specified, relevant spatial
-#'   covariance parameters are assumed unknown, requiring estimation.
-#'   \code{spcov_type} is not required (and is
-#'   ignored) if \code{spcov_initial} is provided. The default for \code{spcov_type}
-#'   is \code{"exponential"}.
+#'   available in Details. Multiple spatial covariance types can be provided as
+#'   a character vector, and then \code{splm()} is called iteratively for each
+#'   element and a list is returned for each model fit. The default for
+#'   \code{spcov_type} is \code{"exponential"}. When \code{spcov_type} is
+#'   specified, all unknown spatial covariance parameters are estimated.
+#'   \code{spcov_type} is ignored if \code{spcov_initial} is provided.
 #' @param xcoord The name of the column in \code{data} representing the x-coordinate.
 #'   Can be quoted or unquoted. Not required if \code{data} is an \code{sf} object.
 #' @param ycoord The name of the column in \code{data} representing the y-coordinate.
 #'   Can be quoted or unquoted. Not required if \code{data} is an \code{sf} object.
 #' @param spcov_initial An object from [spcov_initial()] specifying initial and/or
-#'   known values for the spatial covariance parameters.
+#'   known values for the spatial covariance parameters. Multiple [spcov_initial()]
+#'   objects can be provided in a list. Then \code{splm()} is called iteratively
+#'   for each element and a list is returned for each model fit.
 #' @param estmethod The estimation method. Available options include
 #'   \code{"reml"} for restricted maximum likelihood, \code{"ml"} for maximum
 #'   likelihood, \code{"sv-wls"} for semivariogram weighted least squares,
@@ -198,16 +201,21 @@
 #'   fitting, but their values can be predicted afterwards by running
 #'   \code{predict(object)}.
 #'
-#' @return A list with many components used to return information about
-#'   the fitted model object via summary functions like
-#'   [summary.spmod()] [tidy.spmod()], [augment.spmod()], [glance.spmod()],
-#'   and [plot.spmod()].
-#'   Many other generics are also available for use with the fitted model
-#'   object, including \code{AIC}, \code{AICc},
-#'   \code{anova}, \code{coef}, \code{cooks.distance}, \code{deviance},
-#'   \code{fitted}, \code{formula}, \code{hatvalues}, \code{influence},
+#' @return A list with many elements that store information about
+#'   the fitted model object. If \code{spcov_type} or \code{spcov_initial} are
+#'   length one, the list has class \code{spmod}. Many generic functions that
+#'   summarize model fit are available for \code{spmod} objects, including
+#'   \code{AIC}, \code{AICc}, \code{anova}, \code{augment}, \code{coef},
+#'   \code{cooks.distance}, \code{deviance}, \code{fitted}, \code{formula},
+#'   \code{glance}, \code{glances}, \code{hatvalues}, \code{influence},
 #'   \code{labels}, \code{logLik}, \code{loocv}, \code{model.frame}, \code{model.matrix},
-#'   \code{predict}, \code{print}, \code{pseudoR2},\code{terms}, \code{update}, and \code{vcov}.
+#'   \code{plot}, \code{predict}, \code{print}, \code{pseudoR2}, \code{summary},
+#'   \code{terms}, \code{tidy}, \code{update}, and \code{vcov}. If
+#'   \code{spcov_type} or \code{spcov_initial} are length greater than one, the
+#'   list has class \code{spmod_list} and each element in the list has class
+#'   \code{spmod}. \code{glances} can be used to summarize \code{spmod_list}
+#'   objects, and the aforementioned \code{spmod} generics can be used on each
+#'   individual list element (model fit).
 #'
 #' @note This function does not perform any internal scaling. If optimization is not
 #'   stable due to large extremely large variances, scale relevant variables
@@ -223,7 +231,9 @@
 #' summary(spmod)
 splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estmethod = "reml", weights = "cressie", anisotropy = FALSE, random, randcov_initial, partition_factor, local, ...) {
 
-  # set exponetnial as defaultif nothing specified
+
+
+  # set exponential as default if nothing specified
   if (missing(spcov_type) && missing(spcov_initial)) {
     spcov_type <- "exponential"
     message("No spatial covariance type provided. Assuming \"exponential\".")
@@ -233,6 +243,29 @@ splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estme
     message("Both spcov_type and spcov_initial provided. spcov_initial overriding spcov_type.")
   }
 
+  # iterate if needed
+  if (!missing(spcov_initial) && is.list(spcov_initial[[1]])) {
+    call_list <- as.list(match.call())[-1]
+    penv <- parent.frame()
+    splm_out <- lapply(spcov_initial, function(x) {
+      call_list$spcov_initial <- x
+      do.call("splm", call_list, envir = penv)
+    })
+    names(splm_out) <- paste("spcov_initial", seq_along(spcov_initial), sep = "_")
+    new_splm_out <- structure(splm_out, class = "spmod_list")
+    return(new_splm_out)
+  } else if (!missing(spcov_type) && length(spcov_type) > 1) {
+    call_list <- as.list(match.call())[-1]
+    penv <- parent.frame()
+    splm_out <- lapply(spcov_type, function(x) {
+      call_list$spcov_type <- x
+      do.call("splm", call_list, envir = penv)
+    })
+    names(splm_out) <- spcov_type
+    new_splm_out <- structure(splm_out, class = "spmod_list")
+    return(new_splm_out)
+  }
+
   # set spcov_initial
   if (missing(spcov_initial)) {
     spcov_initial <- spmodel::spcov_initial(spcov_type)
@@ -332,7 +365,7 @@ splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estme
     formula = formula,
     terms = data_object$terms,
     call = match.call(),
-    fn = as.character(as.list(match.call())[[1]]),
+    fn = "splm",
     estmethod = estmethod,
     obdata = data_object$obdata,
     newdata = data_object$newdata,
@@ -349,6 +382,7 @@ splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estme
     missing_index = data_object$missing_index,
     local_index = local_index,
     contrasts = data_object$contrasts,
+    xlevels = data_object$xlevels,
     is_sf = data_object$is_sf,
     sf_column_name = data_object$sf_column_name,
     crs = data_object$crs
